<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:import href="../../../../share/XSLT/descriptionTop.xslt"/>
<xsl:import href="../../../../share/XSLT/indexMenu.xslt"/>

<xsl:param name="pwd"/>

<xsl:output method="xhtml:xhtml"/>

<xsl:variable name="menu">
  <groups xmlns="">
    <group id="interfaces" href="./_interfaceIndex.html" title="interfaces"/>
    <group id="attributes"  href="./_attributeIndex.html"  title="attributes"/>
    <group id="methods" href="./_methodIndex.html" title="methods"/>
    <group id="all" href="./_allIndex.html" title="all refs"/>
  </groups>
</xsl:variable>
 
<xsl:variable name="zvonItemid" select="document('../frontpage.xml')/frontPage/@idref"/>



<xsl:template match="/">
  <xsl:apply-templates select="//module"/>
  <!-- TODO: indexes for all modules together -->
</xsl:template>

<xsl:template match="module">

  <xsl:param name="module"><xsl:value-of select="@name"/></xsl:param>
  <xsl:message>
    MATCH: <xsl:value-of select="$module"/>
  </xsl:message>

  <xsl:document href="{$pwd}Output/{$module}/_interfaceIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (interfaces) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">interfaces</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>interface</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

  <xsl:document href="{$pwd}Output/{$module}/_attributeIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (attributes) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">attributes</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>attribute</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface/attribute">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

  <xsl:document href="{$pwd}Output/{$module}/_methodIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (methods) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">methods</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>method</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface/method">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

  <xsl:document href="{$pwd}Output/{$module}/_allIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (everything) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">all</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>all</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface | descendant::interface/attribute | descendant::interface/method">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

</xsl:template>
 
<xsl:template match="interface">
  <xsl:variable name="desiredName"><xsl:value-of select="@name"/>.html</xsl:variable>
  <tr><td><a class="interface" href="interface_{$desiredName}" target="mainWindow"><xsl:value-of select="@name"/></a></td></tr>
</xsl:template>

<xsl:template match="interface/attribute">
  <tr><td><a class="attributeFg" href="attribute_{@name}_{../@name}.html" target="mainWindow" title="interface {../@name}"><xsl:value-of select="@name"/></a>&#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>]</span></td></tr>
</xsl:template>

<xsl:template match="interface/method">
  <tr><td><a class="methodFg" href="method_{@name}_{../@name}.html" target="mainWindow" title="interface {../@name}"><xsl:value-of select="@name"/>()</a>&#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>()]</span></td></tr>
</xsl:template>



<xsl:template name="index-header-special">
  <xsl:param name="on"/>	<!-- what is highlited -->
  <xsl:param name="id"/>
  <xsl:param name="sectionId"/>	<!-- what is opened -->
  <xsl:param name="url"/>
  <xsl:param name="levelsBack">2</xsl:param>
  <xsl:variable name="field">
    <items xmlns="">
      <a id="Core" class="naviBlack" href="../Core/_{$url}Index.html">Core</a>
      <!--a id="HTML" class="naviBlack" href="../HTML/_{$url}Index.html">HTML</a-->
    </items>
  </xsl:variable>
  <!-- top ZVON navigation -->
  <xsl:call-template name="tinyTopMenu">
    <xsl:with-param name="id" select="$id"/>
    <xsl:with-param name="levelsBack" select="$levelsBack"/>
  </xsl:call-template>
  <!-- TREE modules navigation -->
  <table width="100%" class="descriptionMenu">
  <tr>
    <td class="descriptionMenu">
    <ul>
      <xsl:for-each select="$field/items/a">
        <li>
          <xsl:choose>
            <xsl:when test="@id = $sectionId">
              - <xsl:value-of select="$sectionId"/>
              <ul>
                <xsl:apply-templates select="$menu/groups/*" mode="indexMenu">
                  <xsl:with-param name="id" select="$on"/>
                </xsl:apply-templates>
              </ul>
            </xsl:when>
            <xsl:otherwise>
              + <a class="menu" href=""><xsl:copy-of select="."/></a>
            </xsl:otherwise>
          </xsl:choose>
        </li>
      </xsl:for-each>
    </ul>
    </td>
  </tr>
  </table>
  <hr />
</xsl:template>


</xsl:stylesheet>